quantizationtools.millisecond_pitch_pairs_to_q_events
=====================================================

.. autofunction:: abjad.tools.quantizationtools.millisecond_pitch_pairs_to_q_events.millisecond_pitch_pairs_to_q_events
